#!/bin/sh
echo 'name: HsSyck
version: 0.50
id: HsSyck-0.50-7d577f89f428907c2c2137bff0300a26

license: BSD3
copyright: Audrey Tang, Gaal Yahas, 2005, 2006, 2007, 2008, 2009
maintainer: audreyt@audreyt.org
stability:
homepage:
package-url:
description: This is a simple YAML ('\''Yet Another Markup Language'\'') processor,
             used by the Pugs project for handling data serialization; this can be
             useful for optimization and caching purposes.
             .
             This is an interface to the @syck@ C library for parsing and
             dumping YAML data. It lets you transform textual YAML data into an
             object of type '\''YamlNode'\'', and vice versa, fast.
category: Text, Pugs
author: Audrey Tang
pkgpath: devel/hs-HsSyck
exposed: True
exposed-modules: Data.Yaml.Syck
hidden-modules:
import-dirs: /usr/local/lib/ghc/HsSyck-0.50
library-dirs: /usr/local/lib/ghc/HsSyck-0.50
hs-libraries: HSHsSyck-0.50
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
         syb-0.3.3-daedbadc9dc041093c4210b3087b5f0b
         utf8-string-0.3.6-131bec5ed6c825184d560515f17820d3
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-HsSyck-0.50/html/HsSyck.haddock
haddock-html: /usr/local/share/doc/hs-HsSyck-0.50/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
